-------------------------------------------------------------------------------
--   OCO Source Materials
--
--   Licensed Materials - Property of IBM
--
--   5724-C02
--
--   (C) Copyright IBM Corp. 2003  All Rights Reserved.
--
--   US Government Users Restricted Rights - Use, duplication or
--   disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
-------------------------------------------------------------------------------
--    File Information: %W%
--    Revision: %I%
--    Date: %G% %U%
-------------------------------------------------------------------------------

--****************************************************************************************
------------------------------------------------------------------------------------------
-- Program:    Clean_and_Reset_BWM_warehouse_Delete_tables.sql
-- Author:     Jan Braddock
-- Run cmd:    db2 -tvf Clean_and_Reset_BWM_warehouse_Delete_tables.sql
--
-- Reset the ETL data as if this warehouse pack were just installed except for
-- SHARED components created by this warehouse pack.
--
-- This script is the first of a two-step process to remove warehouse data for the
-- BWM wep. This script will drop tables for the BWM wep. The next script, 
-- Clean_and_Reset_BWM_warehouse_Create_tables.sql, should be run after this script
-- to clean out the CDW tables and recreate the necessary warehouse pack tables.
-- 
-- This script should only be run when all the data for the BWM wep should be 
-- removed from both the CDW and MART databases. The only data that will be 
-- left in the CDW from this wep will be any SHARED components and their relationships. 
-- For this warehouse pack the only SHARED components are the J2EE* components and 
-- the IP_HOST component. Any relations for a SHARED component that had a relation 
-- with BWM component will also be removed.
--
-- Limitations and concerns:
--------------------------------
-- ** This script may run with errors because some tables may not currently
--    exist that are being removed. Ignore errors from this script indicating
--    particular tables did not exist.
--
-- 1) This script should only be run when no warehouse ETL's are being to avoid
--    lock contention.
-- 2) The transactions logs must be sized large enough to handle the data deletion 
--    or the data could be rolled back after running for long periods of time.
-- 3) To improve performance after removing many rows it would be good to update
--    the database statistics.
------------------------------------------------------------------------------------------
--****************************************************************************************

------------------------------------------------------------------------------------------
-- TWH_CDW 
--
-- Change the TWH_CDW below to the correct CDW database name, if different.
--
-- *** You must change _user below to the warehouse DB2 user id for the script to run ***
------------------------------------------------------------------------------------------
CONNECT TO TWH_CDW USER _user;

COMMIT;

----------------------------------------------------
-- Drop COMP_ATTR_LONG objects
----------------------------------------------------
DROP TABLE BWM.COMP_ATTR_LONG;

DROP VIEW BWM.VE_COMP_ATTR_LONG; 

DROP VIEW BWM.VD_COMP_ATTR_LONG; 

--------------------------------------------------
-- Drop BWM.Exception_Log 
--------------------------------------------------
DROP TABLE BWM.Exception_Log ;

--------------------------------------------------
-- Drop any staging tables used in ETL1
--------------------------------------------------
--Staging tables for WTP 5.3
DROP TABLE BWM.STG_HOST;
DROP TABLE BWM.STG_AGENT_GRP;
DROP TABLE BWM.STG_APPLICATION;
DROP TABLE BWM.STG_USER;
DROP TABLE BWM.STG_TRANSACTION;
DROP TABLE BWM.STG_NODE;
DROP TABLE BWM.STG_RELATIONMAP;
DROP TABLE BWM.STG_AGGREG_DATA;
DROP TABLE BWM.STG_MGMTPOLICY;
DROP TABLE BWM.STG_MGMTPOLGRP;
DROP TABLE BWM.STG_PATTERN;
DROP TABLE BWM.STG_THRESHOLD;
DROP TABLE BWM.STG_TR;
DROP TABLE BWM.STG_DUPS;
DROP TABLE BWM.STG_J2EE_DUPS;


------------------------------------------------------------------------------------------
-- TWH_MART
--
-- Change the TWH_MART below to the correct MART database name, if different.
--
-- *** You must change _user below to the warehouse DB2 user id for the script to run ***
------------------------------------------------------------------------------------------
CONNECT TO TWH_MART USER _user;

COMMIT;

-------------------------------------------------------
-- Drop Prune tables
-------------------------------------------------------
DROP TABLE BWM.PRUNE_MART_CONTROL;

DROP TABLE BWM.PRUNE_MART_LOG;

----------------------------
--- Dimension Table:  Host
----------------------------
DROP TABLE BWM.D_HOST;

--SEQUENCE
DROP SEQUENCE BWM.HOST_ID_SEQ RESTRICT;


--TRIGGER
DROP TRIGGER BWM.HOST_IL;

-- Translation table
DROP TABLE BWM.T_HOST;

-----------------------------------
--- Dimension Table:  Agent Group
-----------------------------------
DROP TABLE BWM.D_HOST_AGENT_GRPS;

-- Translation table
DROP TABLE BWM.T_HOST_AGENT_GRPS;
 
-----------------------------
-- dimension table: TX
-----------------------------
DROP TABLE BWM.D_TX;

--sequence
DROP SEQUENCE BWM.TX_ID_SEQ RESTRICT;

--trigger
DROP TRIGGER BWM.TX_IL;

-- translation table
DROP TABLE BWM.T_TX;

------------------------
-- dimension table: APP
------------------------
DROP TABLE BWM.D_APP;

--sequence
DROP SEQUENCE BWM.APP_ID_SEQ RESTRICT;

--trigger
DROP TRIGGER BWM.APP_IL;

-- translation table
DROP TABLE BWM.T_APP;

-----------------------------
-- dimension table: TX_NODE
-----------------------------
DROP TABLE BWM.D_TX_ND;

--sequence
DROP SEQUENCE BWM.TX_ND_ID_SEQ RESTRICT;

--trigger
DROP TRIGGER BWM.TX_ND_IL;

-- translation table
DROP TABLE BWM.T_TX_ND;

------------------------------------
-- dimension table: TX_ND_POL_GRPS
------------------------------------
DROP TABLE BWM.D_TX_ND_POL_GRPS;

-- translation table
DROP TABLE BWM.T_TX_ND_POL_GRPS;

------------------------------------
-- dimension table: TX_NODE metric
------------------------------------
DROP TABLE BWM.D_TX_ND_METRIC; 

--sequence
DROP SEQUENCE BWM.TX_ND_METRIC_ID_SEQ RESTRICT;

--trigger
DROP TRIGGER BWM.TX_ND_METRIC_IL;

-- translation table
DROP TABLE BWM.T_TX_ND_METRIC; 

----------------------------
-- HOURLY fact table
----------------------------
DROP TABLE BWM.F_TX_ND_HOUR; 

--SEQUENCE FOR HOURLY FACT TABLE
DROP SEQUENCE BWM.FACT_ID_SEQ_HR RESTRICT;


--TRIGGER FOR HOURLY FACT TABLE
DROP TRIGGER BWM.FACT_IL_HR;

-----------------------------
-- DAILY fact table
-----------------------------
DROP TABLE BWM.F_TX_ND_DAY;

--SEQUENCE FOR DAILY FACT TABLE
DROP SEQUENCE BWM.FACT_ID_SEQ_DY RESTRICT;

--TRIGGER FOR DAILY FACT TABLE
DROP TRIGGER BWM.FACT_IL_DY;

-----------------------------
-- WEEKLY fact table
-----------------------------
DROP TABLE BWM.F_TX_ND_WEEK;

--SEQUENCE FOR WEEKLY FACT TABLE
DROP SEQUENCE BWM.FACT_ID_SEQ_WK RESTRICT;

--TRIGGER FOR WEEKLY FACT TABLE
DROP TRIGGER BWM.FACT_IL_WK;

-----------------------------
-- MONTHLY fact table
-----------------------------
DROP TABLE BWM.F_TX_ND_MONTH;

--SEQUENCE FOR MONTHLY FACT TABLE
DROP SEQUENCE BWM.FACT_ID_SEQ_MN RESTRICT;

--TRIGGER FOR MONTHLY FACT TABLE
DROP TRIGGER BWM.FACT_IL_MN;

-----------------------------
-- FACT DATA STAGE TABLES
-----------------------------
DROP TABLE BWM.STG_TX_ND_HR;

DROP TABLE BWM.STG1_TX_ND_HR;

DROP TABLE BWM.STG2_TX_ND_HR;

--SEQUENCE
DROP SEQUENCE BWM.STG_MSMT_ID_SEQ RESTRICT;

-----------------------------------------------------------------
-- Drop LONG tables for comp and compattr in the MART database
-----------------------------------------------------------------
DROP TABLE BWM.COMP_NAME_LONG; 

-- Drop comp attr long table
DROP TABLE BWM.COMP_ATTR_LONG; 

--------------------------------------------------------------------------------
-- Drop the exceptions log table
--------------------------------------------------------------------------------
DROP TABLE BWM.Exception_Log ;

DROP VIEW BWM.F_V_TX_ND_999_HOUR; 

DROP VIEW BWM.D_V_HOST_999; 

-------------------------------------------------------------
-- Drop the BWM hourly view for the Crystal reports
-------------------------------------------------------------
DROP VIEW BWM.F_TX_ND_HOUR_VIEW; 


