----------------------------------------------------------------------------------------------------
--   OCO Source Materials
--
--   Licensed Materials - Property of IBM
--
--   5724-C02
--
--   (C) Copyright IBM Corp. 2003  All Rights Reserved.
--
--   US Government Users Restricted Rights - Use, duplication or
--   disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
----------------------------------------------------------------------------------------------------
--    File Information: %W%
--    Revision: %I%
--    Date: %G% %U%
----------------------------------------------------------------------------------------------------

----------------------------------------------------------
-- Create views for the Crystal reports
-- Only run this script if the ITM AMY wep is installed
-- otherwise it will not work because it won't find the
-- tables to create the views from.
----------------------------------------------------------
-- Change the mart name below, TWH_MART, if your mart has
-- a different name.
CONNECT TO TWH_MART;
COMMIT;

-- Create the view of the BWM and AMY hourly fact table for the cross app report
CREATE VIEW BWM.F_X_APP_HR_VIEW (
         HOSTNAME,
         TRAN_MEAS,
         TX_NAME,
         MEAS_VAL,
         MEAS_DATE,
         MEM_USAGE,
         CPU_USAGE
    ) AS
SELECT   H.HOST_NM AS HOSTNAME,
         SUM(F.SAMPLE_COUNT) AS TRAN_COUNT,
         TX.TX_NAME AS TX_NAME,
         'Tran_count' AS MEAS_VAL,
         F.MEAS_HOUR,
         AVG(E.AVG_VALUE) as MEM_USAGE,
         AVG(C.AVG_VALUE) as CPU_USAGE
FROM     BWM.F_TX_ND_HOUR F LEFT OUTER JOIN AMY.F_CPU_HOUR C
              ON F.MEAS_HOUR = C.MEAS_HOUR,
         BWM.F_TX_ND_HOUR F1 LEFT OUTER JOIN AMY.F_MEMORY_HOUR E
              ON F1.MEAS_HOUR = E.MEAS_HOUR,
         AMY.D_HOST_IP I,
         AMY.D_CPU_METRIC CM,
         AMY.D_MEM_METRIC EM,
         BWM.D_TX_ND_METRIC M,
         BWM.D_TX TX,
         BWM.D_HOST H
WHERE    H.HOST_ID = F.HOST_ID and
         C.HOST_ID = I.HOST_ID and
         E.HOST_ID = I.HOST_ID and
         I.HOSTNAME = H.HOST_NM and
         E.METRIC_ID = EM.METRIC_ID and
         EM.MET_NAME = 'PercentMemoryUsage' and
         C.METRIC_ID = CM.METRIC_ID and
         CM.MET_NAME = 'basicAverageCPUPct' and
         F.METRIC_ID = M.METRIC_ID and
         M.MET_NAME = 'Number of Executions' and
         TX.TX_ID = F.TX_ID and
         F.MEAS_HOUR = C.MEAS_HOUR and
         F.MEAS_HOUR = E.MEAS_HOUR
GROUP BY 
         TX.TX_NAME,
         H.HOST_NM,
         F.MEAS_HOUR
UNION
SELECT   H.HOST_NM AS HOSTNAME,
         SUM(F.AVG_VALUE * F.SAMPLE_COUNT) / SUM(F.SAMPLE_COUNT) as TRAN_MEAS,
         TX.TX_NAME AS TX_NAME,
         'Tran_rt' AS MEAS_VAL,
         F.MEAS_HOUR,
         AVG(E.AVG_VALUE) as MEM_USAGE,
         AVG(C.AVG_VALUE) as CPU_USAGE
FROM     BWM.F_TX_ND_HOUR F LEFT OUTER JOIN AMY.F_CPU_HOUR C
              ON F.MEAS_HOUR = C.MEAS_HOUR,
         BWM.F_TX_ND_HOUR F1 LEFT OUTER JOIN AMY.F_MEMORY_HOUR E
              ON F1.MEAS_HOUR = E.MEAS_HOUR,
         AMY.D_HOST_IP I,
         AMY.D_CPU_METRIC CM,
         AMY.D_MEM_METRIC EM,
         BWM.D_TX_ND_METRIC M,
         BWM.D_TX TX,
         BWM.D_HOST H
WHERE    H.HOST_ID = F.HOST_ID and
         C.HOST_ID = I.HOST_ID and
         E.HOST_ID = I.HOST_ID and
         I.HOSTNAME = H.HOST_NM and
         E.METRIC_ID = EM.METRIC_ID and
         EM.MET_NAME = 'PercentMemoryUsage' and
         C.METRIC_ID = CM.METRIC_ID and
         CM.MET_NAME = 'basicAverageCPUPct' and
         F.METRIC_ID = M.METRIC_ID and
         M.MET_NAME = 'Response Time' and
         TX.TX_ID = F.TX_ID and
         F.MEAS_HOUR = C.MEAS_HOUR and
         F.MEAS_HOUR = E.MEAS_HOUR
GROUP BY       
         TX.TX_NAME,
         H.HOST_NM,
         F.MEAS_HOUR
;


-- Create the view of the BWM and AMY daily fact table for the cross app report
CREATE VIEW BWM.F_X_APP_DAY_VIEW (
         HOSTNAME,
         TRAN_MEAS,
         TX_NAME,
         MEAS_VAL,
         MEAS_DATE,
         MEM_USAGE,
         CPU_USAGE
    ) AS
SELECT   H.HOST_NM AS HOSTNAME,
         SUM(F.SAMPLE_COUNT) AS TRAN_COUNT,
         TX.TX_NAME AS TX_NAME,
         'Tran_count' AS MEAS_VAL,
         F.MEAS_DATE,
         AVG(E.AVG_VALUE) as MEM_USAGE,
         AVG(C.AVG_VALUE) as CPU_USAGE
FROM     BWM.F_TX_ND_DAY F LEFT OUTER JOIN AMY.F_CPU_DAY C
              ON F.MEAS_DATE = C.MEAS_DATE,
         BWM.F_TX_ND_DAY F1 LEFT OUTER JOIN AMY.F_MEMORY_DAY E
              ON F1.MEAS_DATE = E.MEAS_DATE,
         AMY.D_HOST_IP I,
         AMY.D_CPU_METRIC CM,
         AMY.D_MEM_METRIC EM,
         BWM.D_TX_ND_METRIC M,
         BWM.D_TX TX,
         BWM.D_HOST H
WHERE    H.HOST_ID = F.HOST_ID and
         C.HOST_ID = I.HOST_ID and
         E.HOST_ID = I.HOST_ID and
         I.HOSTNAME = H.HOST_NM and
         E.METRIC_ID = EM.METRIC_ID and
         EM.MET_NAME = 'PercentMemoryUsage' and
         C.METRIC_ID = CM.METRIC_ID and
         CM.MET_NAME = 'basicAverageCPUPct' and
         F.METRIC_ID = M.METRIC_ID and
         M.MET_NAME = 'Number of Executions' and
         TX.TX_ID = F.TX_ID and
         F.MEAS_DATE = C.MEAS_DATE and
         F.MEAS_DATE = E.MEAS_DATE
GROUP BY 
         TX.TX_NAME,
         H.HOST_NM,
         F.MEAS_DATE
UNION
SELECT   H.HOST_NM AS HOSTNAME,
         SUM(F.AVG_VALUE * F.SAMPLE_COUNT) / SUM(F.SAMPLE_COUNT) as TRAN_MEAS,
         TX.TX_NAME AS TX_NAME,
         'Tran_rt' AS MEAS_VAL,
         F.MEAS_DATE,
         AVG(E.AVG_VALUE) as MEM_USAGE,
         AVG(C.AVG_VALUE) as CPU_USAGE
FROM     BWM.F_TX_ND_DAY F LEFT OUTER JOIN AMY.F_CPU_DAY C
              ON F.MEAS_DATE = C.MEAS_DATE,
         BWM.F_TX_ND_DAY F1 LEFT OUTER JOIN AMY.F_MEMORY_DAY E
              ON F1.MEAS_DATE = E.MEAS_DATE,
         AMY.D_HOST_IP I,
         AMY.D_CPU_METRIC CM,
         AMY.D_MEM_METRIC EM,
         BWM.D_TX_ND_METRIC M,
         BWM.D_TX TX,
         BWM.D_HOST H
WHERE    H.HOST_ID = F.HOST_ID and
         C.HOST_ID = I.HOST_ID and
         E.HOST_ID = I.HOST_ID and
         I.HOSTNAME = H.HOST_NM and
         E.METRIC_ID = EM.METRIC_ID and
         EM.MET_NAME = 'PercentMemoryUsage' and
         C.METRIC_ID = CM.METRIC_ID and
         CM.MET_NAME = 'basicAverageCPUPct' and
         F.METRIC_ID = M.METRIC_ID and
         M.MET_NAME = 'Response Time' and
         TX.TX_ID = F.TX_ID and
         F.MEAS_DATE = C.MEAS_DATE and
         F.MEAS_DATE = E.MEAS_DATE
GROUP BY 
         TX.TX_NAME,
         H.HOST_NM,
         F.MEAS_DATE
;

-- Create the view of the BWM and AMY weekly fact table for the cross app report
CREATE VIEW BWM.F_X_APP_WEEK_VIEW (
         HOSTNAME,
         TRAN_MEAS,
         TX_NAME,
         MEAS_VAL,
         MEAS_DATE,
         MEM_USAGE,
         CPU_USAGE
    ) AS
SELECT   H.HOST_NM AS HOSTNAME,
         SUM(F.SAMPLE_COUNT) AS TRAN_COUNT,
         TX.TX_NAME AS TX_NAME,
         'Tran_count' AS MEAS_VAL,
         F.MEAS_DATE,
         AVG(E.AVG_VALUE) as MEM_USAGE,
         AVG(C.AVG_VALUE) as CPU_USAGE
FROM     BWM.F_TX_ND_WEEK F LEFT OUTER JOIN AMY.F_CPU_WEEK C
              ON F.MEAS_DATE = C.MEAS_DATE,
         BWM.F_TX_ND_WEEK F1 LEFT OUTER JOIN AMY.F_MEMORY_WEEK E
              ON F1.MEAS_DATE = E.MEAS_DATE,
         AMY.D_HOST_IP I,
         AMY.D_CPU_METRIC CM,
         AMY.D_MEM_METRIC EM,
         BWM.D_TX_ND_METRIC M,
         BWM.D_TX TX,
         BWM.D_HOST H
WHERE    H.HOST_ID = F.HOST_ID and
         C.HOST_ID = I.HOST_ID and
         E.HOST_ID = I.HOST_ID and
         I.HOSTNAME = H.HOST_NM and
         E.METRIC_ID = EM.METRIC_ID and
         EM.MET_NAME = 'PercentMemoryUsage' and
         C.METRIC_ID = CM.METRIC_ID and
         CM.MET_NAME = 'basicAverageCPUPct' and
         F.METRIC_ID = M.METRIC_ID and
         M.MET_NAME = 'Number of Executions' and
         TX.TX_ID = F.TX_ID and
         F.MEAS_DATE = C.MEAS_DATE and
         F.MEAS_DATE = E.MEAS_DATE
GROUP BY 
         TX.TX_NAME,
         H.HOST_NM,
         F.MEAS_DATE
UNION
SELECT   H.HOST_NM AS HOSTNAME,
         SUM(F.AVG_VALUE * F.SAMPLE_COUNT) / SUM(F.SAMPLE_COUNT) as TRAN_MEAS,
         TX.TX_NAME AS TX_NAME,
         'Tran_rt' AS MEAS_VAL,
         F.MEAS_DATE,
         AVG(E.AVG_VALUE) as MEM_USAGE,
         AVG(C.AVG_VALUE) as CPU_USAGE
FROM     BWM.F_TX_ND_WEEK F LEFT OUTER JOIN AMY.F_CPU_WEEK C
              ON F.MEAS_DATE = C.MEAS_DATE,
         BWM.F_TX_ND_WEEK F1 LEFT OUTER JOIN AMY.F_MEMORY_WEEK E
              ON F1.MEAS_DATE = E.MEAS_DATE,
         AMY.D_HOST_IP I,
         AMY.D_MEM_METRIC EM,
         AMY.D_CPU_METRIC CM,
         BWM.D_TX_ND_METRIC M,
         BWM.D_TX TX,
         BWM.D_HOST H
WHERE    H.HOST_ID = F.HOST_ID and
         C.HOST_ID = I.HOST_ID and
         E.HOST_ID = I.HOST_ID and
         I.HOSTNAME = H.HOST_NM and
         E.METRIC_ID = EM.METRIC_ID and
         EM.MET_NAME = 'PercentMemoryUsage' and
         C.METRIC_ID = CM.METRIC_ID and
         CM.MET_NAME = 'basicAverageCPUPct' and
         F.METRIC_ID = M.METRIC_ID and
         M.MET_NAME = 'Response Time' and
         TX.TX_ID = F.TX_ID and
         F.MEAS_DATE = C.MEAS_DATE and
         F.MEAS_DATE = E.MEAS_DATE
GROUP BY 
         TX.TX_NAME,
         H.HOST_NM,
         F.MEAS_DATE
;


-- Create the view of the BWM and AMY monthly fact table for the cross app report
CREATE VIEW BWM.F_X_APP_MON_VIEW (
         HOSTNAME,
         TRAN_MEAS,
         TX_NAME,
         MEAS_VAL,
         MEAS_DATE,
         MEM_USAGE,
         CPU_USAGE
    ) AS
SELECT   H.HOST_NM AS HOSTNAME,
         SUM(F.SAMPLE_COUNT) AS TRAN_COUNT,
         TX.TX_NAME AS TX_NAME,
         'Tran_count' AS MEAS_VAL,
         F.MEAS_DATE,
         AVG(E.AVG_VALUE) as MEM_USAGE,
         AVG(C.AVG_VALUE) as CPU_USAGE
FROM     BWM.F_TX_ND_MONTH F LEFT OUTER JOIN AMY.F_CPU_MONTH C
              ON F.MEAS_DATE = C.MEAS_DATE,
         BWM.F_TX_ND_MONTH F1 LEFT OUTER JOIN AMY.F_MEMORY_MONTH E
              ON F1.MEAS_DATE = E.MEAS_DATE,
         AMY.D_HOST_IP I,
         AMY.D_CPU_METRIC CM,
         AMY.D_MEM_METRIC EM,
         BWM.D_TX_ND_METRIC M,
         BWM.D_TX TX,
         BWM.D_HOST H
WHERE    H.HOST_ID = F.HOST_ID and
         C.HOST_ID = I.HOST_ID and
         E.HOST_ID = I.HOST_ID and
         I.HOSTNAME = H.HOST_NM and
         E.METRIC_ID = EM.METRIC_ID and
         EM.MET_NAME = 'PercentMemoryUsage' and
         C.METRIC_ID = CM.METRIC_ID and
         CM.MET_NAME = 'basicAverageCPUPct' and
         F.METRIC_ID = M.METRIC_ID and
         M.MET_NAME = 'Number of Executions' and
         TX.TX_ID = F.TX_ID and
         F.MEAS_DATE = C.MEAS_DATE and
         F.MEAS_DATE = E.MEAS_DATE
GROUP BY       
         TX.TX_NAME,
         H.HOST_NM,
         F.MEAS_DATE
UNION
SELECT   H.HOST_NM AS HOSTNAME,
         SUM(F.AVG_VALUE * F.SAMPLE_COUNT) / SUM(F.SAMPLE_COUNT) as TRAN_MEAS,
         TX.TX_NAME AS TX_NAME,
         'Tran_rt' AS MEAS_VAL,
         F.MEAS_DATE,
         AVG(E.AVG_VALUE) as MEM_USAGE,
         AVG(C.AVG_VALUE) as CPU_USAGE
FROM     BWM.F_TX_ND_MONTH F LEFT OUTER JOIN AMY.F_CPU_MONTH C
              ON F.MEAS_DATE = C.MEAS_DATE,
         BWM.F_TX_ND_MONTH F1 LEFT OUTER JOIN AMY.F_MEMORY_MONTH E
              ON F1.MEAS_DATE = E.MEAS_DATE,
         AMY.D_HOST_IP I,
         AMY.D_CPU_METRIC CM,
         AMY.D_MEM_METRIC EM,
         BWM.D_TX_ND_METRIC M,
         BWM.D_TX TX,
         BWM.D_HOST H
WHERE    H.HOST_ID = F.HOST_ID and
         C.HOST_ID = I.HOST_ID and
         E.HOST_ID = I.HOST_ID and
         I.HOSTNAME = H.HOST_NM and
         E.METRIC_ID = EM.METRIC_ID and
         EM.MET_NAME = 'PercentMemoryUsage' and
         C.METRIC_ID = CM.METRIC_ID and
         CM.MET_NAME = 'basicAverageCPUPct' and
         F.METRIC_ID = M.METRIC_ID and
         M.MET_NAME = 'Response Time' and
         TX.TX_ID = F.TX_ID and
         F.MEAS_DATE = C.MEAS_DATE and
         F.MEAS_DATE = E.MEAS_DATE
GROUP BY 
         TX.TX_NAME,
         H.HOST_NM,
         F.MEAS_DATE
;

